==> moodle-1.9.7.tgz: moodle/lang/en_utf8/moodle.org.php <==
<?php   // $Id: moodle.org.php,v 1.1.2.1 2009/09/15 08:34:03 moodler Exp $

$string['aboutdemosite'] = 'Our demonstration site is a full Moodle site with some sample courses that you can try as a teacher, student or even an administrator.  Don\'t worry about making a mess, the whole site is reset to a clean state every hour.';
$string['aboutdemositetitle'] = 'Demonstration site';
$string['aboutintro'] = 'Moodle is an Open Source Course Management System (CMS), also known as a Learning Management System (LMS) or a Virtual Learning Environment (VLE).  It has become very popular among educators around the world as a tool for creating online dynamic web sites for their students.  To work, it needs to be installed on a web server somewhere, either on one of your own computers or one at a web hosting company.';
$string['aboutoverview'] = '
<p>The focus of the Moodle project is always on giving educators the best tools to manage and promote learning, but there are many ways to use Moodle:</p>
<ul>
<li>Moodle has features that allow it to scale to very large deployments and hundreds of thousands of students, yet it can also be used for a primary school or an education hobbyist.</li>
<li>Many institutions use it as their platform to conduct fully online courses, while some use it simply to augment face-to-face courses (known as blended learning).</li>
<li>Many of our users love to use the many activity modules (such as Forums, Wikis, Databases and so on) to build richly collaborative communities of learning around their subject matter (in the social constructionist tradition), while others prefer to use Moodle as a way to deliver content to students (such as standard SCORM packages) and assess learning using assignments or quizzes.</li>
</ul>
';
$string['aboutoverviewtitle'] = 'What is Moodle?';
$string['aboutstatistics'] = 'Moodle is free to download and registration is voluntary, so we don\'t have full information about everyone that uses it.  However, using what we do know, we automatically generate some interesting graphs and numbers on our Statistics page.';
$string['aboutstatisticstitle'] = 'Statistics';
$string['browsecvstitle'] = 'Browse our source code';
$string['communityintro'] = 'Moodle has a large and diverse user community with over <a href=\"http://moodle.org/userpics\">$a->usercount registered users</a> on this Moodle site alone, speaking over <a href=\"http://download.moodle.org/lang16/\">$a->langcount languages</a> in <a href=\"http://moodle.org/sites\">$a->countrycount countries</a> (we have <a href=\"http://moodle.org/stats\">more statistics</a>).';
$string['conferencecenter'] = 'Moodle Conference Center';
$string['connectedsites'] = 'Some Moodle sites have been connected to moodle.org using Moodle Networking, so you can log in there directly once you are authenticated here.';
$string['connectedsitestitle'] = 'Connected sites';
$string['contactcommunity'] = 'All other queries should go to the Moodle Community Manager.';
$string['contactintro'] = 'Please choose from the following contact options:';
$string['contactlogin'] = 'For all other queries, log in to this site and then use the contact form which will appear on this page.';
$string['contactsent'] = 'Your message was sent via email to the Moodle Community manager.';
$string['contactsupporttitle'] = 'Support';
$string['contactsupport'] = 'For support with using Moodle software, please see our support page which lists many helpful resources available to you.';
$string['contactmoodleorgtitle'] = 'Moodle.org';
$string['contactmoodleorgemail'] = 'For problems with moodle.org account confirmation, email this address:';
$string['contactmoodleorgother'] = 'For all other queries, please use the contact form below.';
$string['contactmoodleorglogin'] =  'Log in to this site now';
$string['contactmoodlecomtitle'] = 'Moodle.com';
$string['contactmoodlecom'] = 'For any queries relating to licensing, trademark or commercial issues, as well as major Moodle developments, please contact the help desk on <a href=\"http://moodle.com/\">Moodle.com</a>';
$string['contactmoodlecomhelpdesk'] = 'Moodle.com Helpdesk';
$string['contactbugstitle'] = 'Bug reporting';
$string['contactbugs'] = 'You can report problems in Moodle software and on any moodle.org site by filing a bug in the Moodle Tracker.';
$string['contactsecurity'] = 'Security issues can also be posted safely in the tracker, providing you set the security level appropriately.';
$string['developercontributors'] = 'Credits';
$string['developerlist'] = 'Full list of developers with write access';
$string['developermeetings'] = 'Developer meetings';
$string['developers'] = 'The main development of Moodle is led by the core team at Moodle.com, helped by hundreds of other developers around the world.  Many of these developers are also directly responsible for various modules and plugins.';
$string['developerstitle'] = 'Developers';
$string['developmentdocs'] = 'The bulk of our documentation is in Moodle Docs - including specifications, brainstorms, procedures, standards and finished user guides.';
$string['developmentdocstitle'] = 'Developer documentation';
$string['developmentintro'] = 'We aim for a transparent and open development process that invites the whole user community to contribute.  We welcome PHP programmers of course, but you can also contribute through discussions, testing, feedback and documentation.';
$string['developmenttracker'] = 'All development issues (such as bugs, new features and improvements) are recorded and managed in the Moodle Tracker. You can see who is working on what, and contribute to any conversation. You should search in the tracker first if you are trying to find out about specific issues, and please make sure you <strong>vote</strong> on the issues you most want to see fixed, as your votes help determine development priorities.';
$string['donations'] = 'Moodle is completely free of financial obligation, however many in the community have donated something to our project to help pay the developers who make it happen.';
$string['donationstitle'] = 'Donations';
$string['downloadcore'] = 'Our main method of distribution is via these standard core packages.  They contain a number of modules that are maintained by core developers, and are convenient for installing on nearly any platform where you have PHP and a database already installed.';
$string['downloadcoretitle'] = 'Standard Moodle packages';
$string['downloadcvs'] = 'Another way to get the core source code is by using CVS to connect directly to one of our mirrors of the code repository used by Moodle developers.  This makes upgrading very easy, even if you have made local changes to the source code.';
$string['downloadcvstitle'] = 'Moodle via CVS';
$string['downloadintro'] = 'Moodle is open source under the <a href=\"http://docs.moodle.org/en/License\">GPL licence</a>.  Everything we produce is available for you to download and use for free.';
$string['downloadlang'] = 'In current versions of Moodle, adding support for new languages has been automated from the administration menu within your site.  However, for some older versions of Moodle, new language packs need to be downloaded manually.';
$string['downloadlangtitle'] = 'Language packs';
$string['downloadlogotitle'] = 'Moodle Logos';
$string['downloadmac'] = 'If you don\'t have a web server set up already, these all-in-one packages make it very easy to install Moodle on any Apple computer running Mac OS X.';
$string['downloadmactitle'] = 'Moodle for Mac OS X';
$string['downloadmodules'] = 'Browse through our comprehensive database of extra modules and plugins that can be added to your Moodle site to give it extra functionality beyond the core packages.';
$string['downloadmodulestitle'] = 'Modules and plugins';
$string['downloadthemes'] = 'The appearance of a Moodle site can be changed dramatically by using a different theme.  We keep a database of themes that Moodle users have created and shared.';
$string['downloadthemestitle'] = 'Themes';
$string['downloadwin'] = 'If you don\'t have a web server set up already, these all-in-one packages make it very easy to install Moodle on any computer running Microsoft Windows.';
$string['downloadwintitle'] = 'Moodle for Windows';
$string['events'] = 'Even though we specialise in online learning, it is still nice to get together in a room!  See these links for more information about our conferences (we call them MoodleMoots) and other events.';
$string['eventstitle'] = 'Events';
$string['frontpagewelcometitle'] = 'Welcome to the Moodle community!';
$string['frontpagewelcome1'] = 'Moodle is a Course Management System (CMS), also known as a Learning Management System (LMS) or a Virtual Learning Environment (VLE).  It is a Free web application that educators can use to create effective online learning sites.';
$string['frontpagewelcome2'] = 'Moodle.org is our community site where Moodle is made and discussed.  Please use the menus to explore and join in!';
$string['generaldeveloperforum'] = 'General developer forum';
$string['jobs'] = 'Visit our jobs database for information on Moodle-related positions world-wide.';
$string['jobstitle'] = 'Moodle Jobs';
$string['moodlecertification'] = 'Moodle Certification';
$string['moodleconsulting'] = 'Moodle Consulting';
$string['moodlecourseware'] = 'Moodle Courseware';
$string['moodlecustomisation'] = 'Moodle Customisation';
$string['moodledocs'] = 'Moodle Docs';
$string['moodlehosting'] = 'Moodle Hosting';
$string['moodleinstallation'] = 'Moodle Installation';
$string['moodleintegrations'] = 'Moodle Integrations';
$string['moodlesupport'] = 'Moodle Support';
$string['moodlethemes'] = 'Moodle Themes';
$string['moodletrackertitle'] = 'Moodle Tracker';
$string['moodletraining'] = 'Moodle Training';
$string['mycoursesintro'] = 'You are currently enrolled in the following \"courses\" on this community site, each containing one or more forums.';
$string['nameabout'] = 'About';
$string['nameaboutmoodle'] = 'About Moodle';
$string['namecommercial'] = 'Commercial services';
$string['namecommunity'] = 'Community';
$string['namecontact'] = 'Contact';
$string['namedevelopment'] = 'Development';
$string['namedocumentation'] = 'Documentation';
$string['namedownloads'] = 'Downloads';
$string['nameevents'] = 'Events';
$string['nameforums'] = 'Forums';
$string['namehome'] = 'Home page';
$string['namemycourses'] = 'My courses';
$string['namenetwork'] = 'Connected sites';
$string['namenews'] = 'News';
$string['namesecurity'] = 'Security news';
$string['namesupport'] = 'Support';
$string['networkintro'] = 'The following Moodle sites have been connected to moodle.org using Moodle networking, so you can log in there directly from here.';
$string['newsbuzz'] = 'Moodle Buzz';
$string['newsbuzzdetail'] = 'Moodle-related publications from the world';
$string['newscalendar'] = 'Calendar';
$string['newscalendardetail'] = 'Moodle-related events in the future';
$string['newsofficial'] = 'Official news about Moodle';
$string['newsplanet'] = 'Planet Moodle';
$string['newsplanetdetail'] = 'Aggregated blogs from Moodle developers';
$string['newsrecent'] = 'Recent news';
$string['newssecurity'] = 'Security news';
$string['newssecuritydetail'] = 'Important information about security issues';
$string['noenrolledcoursesyet'] = 'You haven\'t enrolled in any courses on this site yet';
$string['overview'] = 'Overview';
$string['overviewabout'] = 'An overview about Moodle';
$string['overviewcommunity'] = 'An overview of the Moodle community';
$string['overviewdevelopment'] = 'An overview of Moodle development';
$string['overviewdownloads'] = 'An overview of Moodle downloads';
$string['overviewmy'] = 'See all the moodle.org courses you are enrolled in';
$string['overviewnews'] = 'An overview of current Moodle news';
$string['overviewsupport'] = 'An overview of Moodle support options';
$string['popularissues'] = 'Most popular issues';
$string['recentpart'] = 'This page shows some of the people using moodle.org today.';
$string['recentparttitle'] = 'Recent participants';
$string['registeredsites'] = 'Institutions are not required to inform anyone when they use Moodle, because Moodle is open source.  However, some Moodle sites have chosen to register with us and we keep a listing of them.';
$string['registeredsitestitle'] = 'Registered sites';
$string['roadmap'] = 'Moodle Roadmap';
$string['shop'] = 'Looking for some way to show you are part of our community?  See out shop for shirts, mugs and all kinds of other things.';
$string['shoptitle'] = 'Moodle Shop';
$string['sourcecodetitle'] = 'Open source code';
$string['supportbooks'] = 'We maintain a listing of many Moodle books available for purchase.';
$string['supportbookstitle'] = 'Books and manuals';
$string['supportcommercial'] = 'The <a href=\"http://moodle.com/\">Moodle Partners</a> are a worldwide group of authorised service companies committed to financially supporting the open source Moodle project. They provide a range of optional commercial services for Moodle users around the world:';
$string['supportcommercialtitle'] = 'Commercial services';
$string['supportdocs1'] = 'Moodle Docs is a great place to start, especially our Frequently Asked Questions (FAQ) pages.';
$string['supportdocs2'] = 'A nice way to access relevant documentation is to use the \"Moodle Docs for this page\" link at the bottom of each page on your own Moodle site.';
$string['supportdocsfaq'] = 'Frequently Asked Questions';
$string['supportdocslang'] = 'Moodle Docs in other languages';
$string['supportdocstitle'] = 'Documentation';
$string['supportforums'] = 'Our user community mostly communicates via forums inside \"courses\" on this Moodle-based site.  You must \"enrol\" in the course to post to forums (enrolment is completely free).';
$string['supportforumsenglish'] = 'The main support and developer discussions between users and developers are in English here:';
$string['supportforumsenglishname'] = 'Using Moodle';
$string['supportforumslang'] = 'The key forum for Moodlers to socialise in English is here:';
$string['supportforumslangname'] = 'Moodle Lounge';
$string['supportforumslangurl'] = 'http://moodle.org/course/view.php?id=55';
$string['supportforumslist'] = 'We have many other forums too, in many languages:';
$string['supportforumslistname'] = 'List of all forums';
$string['supportforumstitle'] = 'Forums';
$string['supportintro'] = 'You are not alone!  There are a variety of ways to get help with Moodle if you need it.';

==> moodle-1.9.16.tgz: moodle/lang/en_utf8/moodle.org.php <==
<?php   // $Id: moodle.org.php,v 1.1.2.5 2011/08/11 22:45:39 moodlerobot Exp $

$string['aboutdemosite'] = 'Our demonstration site is a full Moodle site with some sample courses that you can try as a teacher, student or even an administrator.  Don\'t worry about making a mess, the whole site is reset to a clean state every hour.';
$string['aboutdemositetitle'] = 'Demonstration site';
$string['aboutintro'] = 'Moodle is an Open Source Course Management System (CMS), also known as a Learning Management System (LMS) or a Virtual Learning Environment (VLE).  It has become very popular among educators around the world as a tool for creating online dynamic web sites for their students.  To work, it needs to be installed on a web server somewhere, either on one of your own computers or one at a web hosting company.';
$string['aboutoverview'] = '
<p>The focus of the Moodle project is always on giving educators the best tools to manage and promote learning, but there are many ways to use Moodle:</p>
<ul>
<li>Moodle has features that allow it to scale to very large deployments and hundreds of thousands of students, yet it can also be used for a primary school or an education hobbyist.</li>
<li>Many institutions use it as their platform to conduct fully online courses, while some use it simply to augment face-to-face courses (known as blended learning).</li>
<li>Many of our users love to use the activity modules (such as forums, databases and wikis) to build richly collaborative communities of learning around their subject matter (in the social constructionist tradition), while others prefer to use Moodle as a way to deliver content to students (such as standard SCORM packages) and assess learning using assignments or quizzes.</li>
</ul>
';
$string['aboutoverviewtitle'] = 'What is Moodle?';
$string['aboutstatistics'] = 'Moodle is free to download and registration is voluntary, so we don\'t have full information about everyone that uses it.  However, using what we do know, we automatically generate some interesting graphs and numbers on our Statistics page.';
$string['aboutstatisticstitle'] = 'Statistics';
$string['browsecvstitle'] = 'Browse our source code';
$string['communityintro'] = 'Moodle has a large and diverse user community with over <a href=\"http://moodle.org/userpics\">$a->usercount registered users</a> on this Moodle site alone, speaking over <a href=\"http://download.moodle.org/lang16/\">$a->langcount languages</a> in <a href=\"http://moodle.org/sites\">$a->countrycount countries</a> (we have <a href=\"http://moodle.org/stats\">more statistics</a>).';
$string['conferencecenter'] = 'Moodle Conference Center';
$string['connectedsites'] = 'Some Moodle sites have been connected to moodle.org using Moodle Networking, so you can log in there directly once you are authenticated here.';
$string['connectedsitestitle'] = 'Connected sites';
$string['contactintro'] = 'Please choose from the following contact options:';
$string['contactlogin'] = 'For all other queries, log in to this site and then use the contact form which will appear on this page.';
$string['contactsent'] = 'Your message was sent via email to the Moodle Community Manager.';
$string['contactsupporttitle'] = 'Support';
$string['contactsupport'] = 'For support with using Moodle software, please see our support page which lists many helpful resources available to you.';
$string['contactmoodleorgtitle'] = 'Moodle.org';
$string['contactmoodleorgemail'] = 'For problems with moodle.org account confirmation, email this address:';
$string['contactmoodleorgother'] = 'For all other queries, please use the contact form below.';
$string['contactmoodleorglogin'] =  'Log in to this site now';
$string['contactmoodlecomtitle'] = 'Moodle.com';
$string['contactmoodlecom'] = 'For any queries relating to licensing, trademark or commercial issues, as well as major Moodle developments, please contact the helpdesk on <a href=\"http://moodle.com/\">Moodle.com</a>';
$string['contactmoodlecomhelpdesk'] = 'Moodle.com helpdesk';
$string['contactbugstitle'] = 'Bug reporting';
$string['contactbugs'] = 'You can report problems in Moodle software and on any moodle.org site by creating a new issue in the Moodle Tracker.';
$string['contactsecurity'] = 'Security issues can also be reported safely in the tracker, providing you set the security level appropriately.';
$string['developercontributors'] = 'Credits';
$string['developerlist'] = 'Full list of developers with write access';
$string['developermeetings'] = 'Developer meetings';
$string['developers'] = 'The main development of Moodle is led by the core team at Moodle.com, helped by hundreds of other developers around the world.  Many of these developers are also directly responsible for various modules and plugins.';
$string['developerstitle'] = 'Developers';
$string['developmentdocs'] = 'The bulk of our documentation is in Moodle Docs - including specifications, brainstorms, procedures, standards and user guides.';
$string['developmentdocstitle'] = 'Developer documentation';
$string['developmentintro'] = 'We aim for a transparent and open development process that invites the whole user community to contribute.  We welcome PHP programmers of course, but you can also contribute through discussions, testing, feedback and documentation.';
$string['developmenttracker'] = 'All development issues (such as bugs, new features and improvements) are recorded and managed in the Moodle Tracker. You can see who is working on what, and contribute to any conversation. You should search in the tracker first if you are trying to find out about specific issues, and please make sure you <strong>vote</strong> on the issues you most want to see fixed, as your votes help determine development priorities.';
$string['donations'] = 'Moodle is completely free of financial obligation, however many in the community have donated something to our project to help pay the developers who make it happen.';
$string['donationstitle'] = 'Donations';
$string['downloadcore'] = 'Our main method of distribution is via these standard core packages.  They contain a number of modules that are maintained by core developers, and are convenient for installing on nearly any platform where you have PHP and a database already installed.';
$string['downloadcoretitle'] = 'Standard Moodle packages';
$string['downloadcvs'] = 'Another way to get the core source code is by using CVS to connect directly to one of our mirrors of the code repository used by Moodle developers.  This makes upgrading very easy, even if you have made local changes to the source code.';
$string['downloadcvstitle'] = 'Moodle via CVS';
$string['downloadintro'] = 'Moodle is open source under the <a href=\"http://docs.moodle.org/dev/License\">GPL licence</a>.  Everything we produce is available for you to download and use for free.';
$string['downloadlang'] = 'In current versions of Moodle, adding support for new languages has been automated from the administration menu within your site.  However, for some older versions of Moodle, new language packs need to be downloaded manually.';
$string['downloadlangtitle'] = 'Language packs';
$string['downloadlogotitle'] = 'Moodle logos';
$string['downloadmac'] = 'If you don\'t have a web server set up already, these all-in-one packages make it very easy to install Moodle on any Apple computer running Mac OS X.';
$string['downloadmactitle'] = 'Moodle for Mac OS X';
$string['downloadmodules'] = 'Browse through our comprehensive database of extra modules and plugins that can be added to your Moodle site to give it extra functionality beyond the core packages.';
$string['downloadmodulestitle'] = 'Modules and plugins';
$string['downloadthemes'] = 'The appearance of a Moodle site can be changed dramatically by using a different theme.  We keep a database of themes that Moodle users have created and shared.';
$string['downloadthemestitle'] = 'Themes';
$string['downloadwin'] = 'If you don\'t have a web server set up already, these all-in-one packages make it very easy to install Moodle on any computer running Microsoft Windows.';
$string['downloadwintitle'] = 'Moodle for Windows';
$string['events'] = 'Even though we specialise in online learning, it is still nice to get together in a room!  See these links for more information about our conferences (we call them MoodleMoots) and other events.';
$string['eventstitle'] = 'Events';
$string['frontpagewelcometitle'] = 'Welcome to the Moodle community!';
$string['frontpagewelcome1'] = 'Moodle is a Course Management System (CMS), also known as a Learning Management System (LMS) or a Virtual Learning Environment (VLE).  It is a Free web application that educators can use to create effective online learning sites.';
$string['frontpagewelcome2'] = 'Moodle.org is our community site where Moodle is made and discussed.  Please use the menus to explore and join in!';
$string['generaldeveloperforum'] = 'General developer forum';
$string['jobs'] = 'Visit our jobs database for information on Moodle-related positions world-wide.';
$string['jobstitle'] = 'Moodle Jobs';
$string['moodlecertification'] = 'Moodle Certification';
$string['moodleconsulting'] = 'Moodle Consulting';
$string['moodlecourseware'] = 'Moodle Courseware';
$string['moodlecustomisation'] = 'Moodle Customisation';
$string['moodledocs'] = 'Moodle Docs';
$string['moodlehosting'] = 'Moodle Hosting';
$string['moodleinstallation'] = 'Moodle Installation';
$string['moodleintegrations'] = 'Moodle Integrations';
$string['moodlesupport'] = 'Moodle Support';
$string['moodlethemes'] = 'Moodle Themes';
$string['moodletrackertitle'] = 'Moodle Tracker';
$string['moodletraining'] = 'Moodle Training';
$string['mycoursesintro'] = 'You are currently enrolled in the following \"courses\" on this community site, each containing one or more forums.';
$string['nameabout'] = 'About';
$string['nameaboutmoodle'] = 'About Moodle';
$string['namecommercial'] = 'Commercial services';
$string['namecommunity'] = 'Community';
$string['namecontact'] = 'Contact';
$string['namedevelopment'] = 'Development';
$string['namedocumentation'] = 'Documentation';
$string['namedownloads'] = 'Downloads';
$string['nameevents'] = 'Events';
$string['nameforums'] = 'Forums';
$string['namemycourses'] = 'My courses';
$string['namenetwork'] = 'Connected sites';
$string['namenews'] = 'News';
$string['namesecurity'] = 'Security news';
$string['namesupport'] = 'Support';
$string['networkintro'] = 'The following Moodle sites have been connected to moodle.org using Moodle networking, so you can log in there directly from here.';
$string['newsbuzz'] = 'Moodle Buzz';
$string['newsbuzzdetail'] = 'Moodle-related publications from around the world';
$string['newscalendar'] = 'Calendar';
$string['newscalendardetail'] = 'Moodle-related events in the future';
$string['newsofficial'] = 'Official news about Moodle';
$string['newsplanet'] = 'Planet Moodle';
$string['newsplanetdetail'] = 'Aggregated blogs from Moodle developers';
$string['newsrecent'] = 'Recent news';
$string['newssecurity'] = 'Security news';
$string['newssecuritydetail'] = 'Important information about security issues';
$string['noenrolledcoursesyet'] = 'You haven\'t enrolled in any courses on this site yet';
$string['overviewabout'] = 'An overview about Moodle';
$string['overviewcommunity'] = 'An overview of the Moodle community';
$string['overviewdevelopment'] = 'An overview of Moodle development';
$string['overviewdownloads'] = 'An overview of Moodle downloads';
$string['overviewmy'] = 'See all the moodle.org courses you are enrolled in';
$string['overviewnews'] = 'An overview of current Moodle news';
$string['overviewsupport'] = 'An overview of Moodle support options';
$string['popularissues'] = 'Most popular issues';
$string['recentpart'] = 'This page shows some of the people using moodle.org today.';
$string['recentparttitle'] = 'Recent participants';
$string['registeredsites'] = 'Institutions are not required to inform anyone when they use Moodle, because Moodle is open source.  However, some Moodle sites have chosen to register with us and we keep a listing of them.';
$string['registeredsitestitle'] = 'Registered sites';
$string['roadmap'] = 'Moodle Roadmap';
$string['shop'] = 'Looking for some way to show you are part of our community?  See out shop for shirts, mugs and all kinds of other things.';
$string['shoptitle'] = 'Moodle Shop';
$string['sourcecodetitle'] = 'Open source code';
$string['supportbooks'] = 'We maintain a listing of many Moodle books available for purchase.';
$string['supportbookstitle'] = 'Books and manuals';
$string['supportcommercial'] = 'The <a href=\"http://moodle.com/\">Moodle Partners</a> are a worldwide group of authorised service companies committed to financially supporting the open source Moodle project. They provide a range of optional commercial services for Moodle users around the world:';
$string['supportcommercialtitle'] = 'Commercial services';
$string['supportdocs1'] = 'Moodle Docs is a great place to start, especially our Frequently Asked Questions (FAQ) pages.';
$string['supportdocs2'] = 'A nice way to access relevant documentation is to use the \"Moodle Docs for this page\" link at the bottom of each page on your own Moodle site.';
$string['supportdocsfaq'] = 'Frequently Asked Questions';
$string['supportdocslang'] = 'Moodle Docs in other languages';
$string['supportdocstitle'] = 'Documentation';
$string['supportforums'] = 'Our user community mostly communicates via forums inside \"courses\" on this Moodle-based site.  You must \"enrol\" in the course to post to forums (enrolment is completely free).';
$string['supportforumsenglish'] = 'The main support and developer discussions between users and developers are in English here:';
$string['supportforumsenglishname'] = 'Using Moodle';
$string['supportforumslang'] = 'The key forum for Moodlers to socialise in English is here:';
$string['supportforumslangname'] = 'Moodle Lounge';
$string['supportforumslangurl'] = 'http://moodle.org/course/view.php?id=55';
$string['supportforumslist'] = 'We have many other forums too, in many languages:';
$string['supportforumslistname'] = 'List of all forums';
$string['supportforumstitle'] = 'Forums';
$string['supportintro'] = 'You are not alone!  There are a variety of ways to get help with Moodle if you need it.';
